==> haskell-insert-ordered-containers-0.2.5.3-191.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-Dukg6b3O0oB3rj9hcuMQqG
key:                  insert-ordered-containers-0.2.5.3-Dukg6b3O0oB3rj9hcuMQqG
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  f23cb67b8a4ed22ec330a89251dec5b9
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-Dukg6b3O0oB3rj9hcuMQqG
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    optics-core-0.4.1.1-3uSkdT24fvM6dyJIU7nYms
    optics-extra-0.4.2.1-9jQ9m1s2Aam5lHDuMP8Ysn
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.5.3-192-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 insert-ordered-containers
version:              0.2.5.3
visibility:           public
id:                   insert-ordered-containers-0.2.5.3-F3ZWofUloJ3FcOrvJbOGyb
key:                  insert-ordered-containers-0.2.5.3-F3ZWofUloJ3FcOrvJbOGyb
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/insert-ordered-containers#readme
synopsis:
    Associative containers retaining insertion order for traversals.

description:
    Associative containers retaining insertion order for traversals.

    The implementation is based on `unordered-containers`.

category:             Web
abi:                  749567e98e0ce7cefe9af4a39e6df1bc
exposed:              True
exposed-modules:      Data.HashMap.Strict.InsOrd Data.HashSet.InsOrd
hidden-modules:       Data.HashMap.InsOrd.Internal
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/insert-ordered-containers-0.2.5.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-insert-ordered-containers
hs-libraries:         HSinsert-ordered-containers-0.2.5.3-F3ZWofUloJ3FcOrvJbOGyb
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    optics-core-0.4.1.1-3uSkdT24fvM6dyJIU7nYms
    optics-extra-0.4.2.1-IUPuKCjD5L4GudJxpQkjve
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock

haddock-html:         /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
